from django.utils.deprecation import MiddlewareMixin
from rest_framework_simplejwt.authentication import JWTAuthentication

class JWTauthenticationMiddleware(MiddlewareMixin):
    def process_request(self, request):
        _user = JWTAuthentication().authenticate(request)
        request.user = _user[0] if _user != None else request.user


import os
import re
from setuptools import find_packages, setup

def get_version():
    init_py = open(os.path.join(package, '__init__.py')).read()
    return re.search("__version__ = ['\"]([^'\"]+)['\"]", init_py).group(1)
    
with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='dsm-django-socialauth',
    version='1.0.10',
    url='https://gitlab.com/public-project2/dsm-django-oauth',
    packages=find_packages(),
    include_package_data=True,
    license='MIT License',
    description='A simple way to use Custom authentication in django application. for dsm',
    long_description=README,
    long_description_content_type='text/markdown',
    author='DigitalStoreMesh Co.,Ltd',
    author_email='contact@storemesh.com',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 4.0',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    install_requires=[
       'social-auth-app-django',
       'djangorestframework-simplejwt'
    ]
)